Conventions — moke 1.1.6 documentation

### Navigation

- index
- modules |
- next |
- previous |
- moke 1.1.6 documentation »

# Conventions

#### Previous topic

`moke` is not like `make`

#### Next topic

Example

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- moke 1.1.6 documentation »

© Copyright 2013, Marcin Cieslik. Created using Sphinx 1.1.3.